@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,23 +15,26 @@
 #
 
 from .services.auto_suggestion_service import AutoSuggestionServiceClient
+from .services.auto_suggestion_service import AutoSuggestionServiceAsyncClient
 from .services.question_service import QuestionServiceClient
+from .services.question_service import QuestionServiceAsyncClient
+
 from .types.annotated_string import AnnotatedString
-from .types.auto_suggestion_service import SuggestQueriesRequest
-from .types.auto_suggestion_service import SuggestQueriesResponse
 from .types.auto_suggestion_service import Suggestion
 from .types.auto_suggestion_service import SuggestionInfo
+from .types.auto_suggestion_service import SuggestQueriesRequest
+from .types.auto_suggestion_service import SuggestQueriesResponse
 from .types.auto_suggestion_service import SuggestionType
 from .types.question import BigQueryJob
 from .types.question import DataQuery
 from .types.question import DebugFlags
 from .types.question import ExecutionInfo
 from .types.question import HumanReadable
-from .types.question import InterpretEntity
-from .types.question import InterpretError
 from .types.question import Interpretation
 from .types.question import InterpretationStructure
+from .types.question import InterpretError
 from .types.question import Question
+from .types.question import InterpretEntity
 from .types.question_service import CreateQuestionRequest
 from .types.question_service import ExecuteQuestionRequest
 from .types.question_service import GetQuestionRequest
@@ -40,8 +42,9 @@ from .types.question_service import GetUserFeedbackRequest
 from .types.question_service import UpdateUserFeedbackRequest
 from .types.user_feedback import UserFeedback
 
-
 __all__ = (
+    "AutoSuggestionServiceAsyncClient",
+    "QuestionServiceAsyncClient",
     "AnnotatedString",
     "AutoSuggestionServiceClient",
     "BigQueryJob",
@@ -58,6 +61,7 @@ __all__ = (
     "Interpretation",
     "InterpretationStructure",
     "Question",
+    "QuestionServiceClient",
     "SuggestQueriesRequest",
     "SuggestQueriesResponse",
     "Suggestion",
@@ -65,5 +69,4 @@ __all__ = (
     "SuggestionType",
     "UpdateUserFeedbackRequest",
     "UserFeedback",
-    "QuestionServiceClient",
 )
