@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,10 +20,10 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.dataqna_v1alpha.types import question
@@ -33,10 +31,9 @@ from google.cloud.dataqna_v1alpha.types import question as gcd_question
 from google.cloud.dataqna_v1alpha.types import question_service
 from google.cloud.dataqna_v1alpha.types import user_feedback
 from google.cloud.dataqna_v1alpha.types import user_feedback as gcd_user_feedback
-from google.protobuf import any_pb2 as gp_any  # type: ignore
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import any_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import QuestionServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import QuestionServiceGrpcAsyncIOTransport
 from .client import QuestionServiceClient
@@ -73,42 +70,67 @@ class QuestionServiceAsyncClient:
     parse_user_feedback_path = staticmethod(
         QuestionServiceClient.parse_user_feedback_path
     )
-
     common_billing_account_path = staticmethod(
         QuestionServiceClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         QuestionServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(QuestionServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         QuestionServiceClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         QuestionServiceClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         QuestionServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(QuestionServiceClient.common_project_path)
     parse_common_project_path = staticmethod(
         QuestionServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(QuestionServiceClient.common_location_path)
     parse_common_location_path = staticmethod(
         QuestionServiceClient.parse_common_location_path
     )
 
-    from_service_account_file = QuestionServiceClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            QuestionServiceAsyncClient: The constructed client.
+        """
+        return QuestionServiceClient.from_service_account_info.__func__(QuestionServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            QuestionServiceAsyncClient: The constructed client.
+        """
+        return QuestionServiceClient.from_service_account_file.__func__(QuestionServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> QuestionServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             QuestionServiceTransport: The transport used by the client instance.
@@ -122,12 +144,12 @@ class QuestionServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, QuestionServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the question service client.
+        """Instantiates the question service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -159,7 +181,6 @@ class QuestionServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = QuestionServiceClient(
             credentials=credentials,
             transport=transport,
@@ -179,16 +200,16 @@ class QuestionServiceAsyncClient:
         r"""Gets a previously created question.
 
         Args:
-            request (:class:`~.question_service.GetQuestionRequest`):
+            request (:class:`google.cloud.dataqna_v1alpha.types.GetQuestionRequest`):
                 The request object. A request to get a previously
                 created question.
             name (:class:`str`):
                 Required. The unique identifier for the question.
                 Example: ``projects/foo/locations/bar/questions/1234``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -196,7 +217,7 @@ class QuestionServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.question.Question:
+            google.cloud.dataqna_v1alpha.types.Question:
                 The question resource represents a
                 natural language query, its settings,
                 understanding generated by the system,
@@ -218,7 +239,6 @@ class QuestionServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -255,22 +275,22 @@ class QuestionServiceAsyncClient:
         r"""Creates a question.
 
         Args:
-            request (:class:`~.question_service.CreateQuestionRequest`):
+            request (:class:`google.cloud.dataqna_v1alpha.types.CreateQuestionRequest`):
                 The request object. Request to create a question
                 resource.
             parent (:class:`str`):
                 Required. The name of the project this data source
                 reference belongs to. Example:
                 ``projects/foo/locations/bar``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            question (:class:`~.gcd_question.Question`):
+            question (:class:`google.cloud.dataqna_v1alpha.types.Question`):
                 Required. The question to create.
                 This corresponds to the ``question`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -278,7 +298,7 @@ class QuestionServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.gcd_question.Question:
+            google.cloud.dataqna_v1alpha.types.Question:
                 The question resource represents a
                 natural language query, its settings,
                 understanding generated by the system,
@@ -300,7 +320,6 @@ class QuestionServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if question is not None:
@@ -339,22 +358,23 @@ class QuestionServiceAsyncClient:
         r"""Executes an interpretation.
 
         Args:
-            request (:class:`~.question_service.ExecuteQuestionRequest`):
+            request (:class:`google.cloud.dataqna_v1alpha.types.ExecuteQuestionRequest`):
                 The request object. Request to execute an
                 interpretation.
             name (:class:`str`):
                 Required. The unique identifier for the question.
                 Example: ``projects/foo/locations/bar/questions/1234``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             interpretation_index (:class:`int`):
                 Required. Index of the interpretation
                 to execute.
+
                 This corresponds to the ``interpretation_index`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -362,7 +382,7 @@ class QuestionServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.question.Question:
+            google.cloud.dataqna_v1alpha.types.Question:
                 The question resource represents a
                 natural language query, its settings,
                 understanding generated by the system,
@@ -384,7 +404,6 @@ class QuestionServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
         if interpretation_index is not None:
@@ -422,17 +441,17 @@ class QuestionServiceAsyncClient:
         r"""Gets previously created user feedback.
 
         Args:
-            request (:class:`~.question_service.GetUserFeedbackRequest`):
+            request (:class:`google.cloud.dataqna_v1alpha.types.GetUserFeedbackRequest`):
                 The request object. Request to get user feedback.
             name (:class:`str`):
                 Required. The unique identifier for the user feedback.
                 User feedback is a singleton resource on a Question.
                 Example:
                 ``projects/foo/locations/bar/questions/1234/userFeedback``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -440,7 +459,7 @@ class QuestionServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.user_feedback.UserFeedback:
+            google.cloud.dataqna_v1alpha.types.UserFeedback:
                 Feedback provided by a user.
         """
         # Create or coerce a protobuf request object.
@@ -457,7 +476,6 @@ class QuestionServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -486,7 +504,7 @@ class QuestionServiceAsyncClient:
         request: question_service.UpdateUserFeedbackRequest = None,
         *,
         user_feedback: gcd_user_feedback.UserFeedback = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -495,24 +513,24 @@ class QuestionServiceAsyncClient:
         there was none before (upsert).
 
         Args:
-            request (:class:`~.question_service.UpdateUserFeedbackRequest`):
+            request (:class:`google.cloud.dataqna_v1alpha.types.UpdateUserFeedbackRequest`):
                 The request object. Request to updates user feedback.
-            user_feedback (:class:`~.gcd_user_feedback.UserFeedback`):
+            user_feedback (:class:`google.cloud.dataqna_v1alpha.types.UserFeedback`):
                 Required. The user feedback to
                 update. This can be called even if there
                 is no user feedback so far. The
                 feedback's name field is used to
                 identify the user feedback (and the
                 corresponding question) to update.
+
                 This corresponds to the ``user_feedback`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
                 The list of fields to be updated.
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -520,7 +538,7 @@ class QuestionServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.gcd_user_feedback.UserFeedback:
+            google.cloud.dataqna_v1alpha.types.UserFeedback:
                 Feedback provided by a user.
         """
         # Create or coerce a protobuf request object.
@@ -537,7 +555,6 @@ class QuestionServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if user_feedback is not None:
             request.user_feedback = user_feedback
         if update_mask is not None:
